@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2021 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2021-2024 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -19,6 +19,8 @@
 
 #include "highlighter.h"
 
+#include <algorithm>
+
 namespace FeatherPad {
 
 // Check whether the start bracket/brace is escaped. FIXME: This only covers keys and values.
@@ -96,7 +98,7 @@ bool Highlighter::yamlOpenBraces (const QString &text,
                 -- openNests;
                 if (openNests == 0)
                     setFormat (startIndx, indx + match.capturedLength() - startIndx, neutralFormat);
-                openNests = qMax (openNests, 0);
+                openNests = std::max (openNests, 0);
             }
         }
         else
@@ -144,11 +146,7 @@ void Highlighter::yamlLiteralBlock (const QString &text)
     QRegularExpressionMatch match;
     if (previousBlockState() == codeBlockState) // the literal block may continue
     {
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-        text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
-#else
         (void)text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
-#endif
         QString startingSpaces = "i" + match.captured();
         if (text == match.captured() // only whitespaces...
             /* ... or the indentation is wider than that of the literal block */
@@ -165,16 +163,22 @@ void Highlighter::yamlLiteralBlock (const QString &text)
     /* the start of a literal block (which is formatted near the end of the main formatting
        because, if it was formatted here, its format might be overridden by that of a value) */
     static const QRegularExpression yamlBlockStartExp ("^(?!#)(?:(?!\\s#).)*\\s+\\K(\\||>)-?\\s*(?=\\s#|$)");
+    static const QRegularExpression yamlKey ("\\s*[^\\s\"\'#][^:,#]*:\\s+");
     int index = text.indexOf (yamlBlockStartExp, 0);
     if (index >= 0)
     {
+        if (text.contains (yamlKey))
+        { // consider the list sign as a space if the block is a value
+            (void)text.indexOf (QRegularExpression ("^\\s*(-\\s)?\\s*"), 0, &match);
+        }
+        else
+        {
+            if (text.indexOf (QRegularExpression ("^\\s*-\\s")) == -1)
+                return; // if the block isn't a value, it should be a list
+            (void)text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
+        }
         setCurrentBlockState (codeBlockState);
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-        text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
-#else
-        (void)text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
-#endif
-        data->insertInfo ("i" + match.captured());
+        data->insertInfo ("i" + match.captured().replace ("-", " "));
     }
 }
 /*************************/
@@ -270,7 +274,11 @@ void Highlighter::highlightYamlBlock (const QString &text)
     {
         data->setHighlighted();
         QRegularExpressionMatch match;
+#if (QT_VERSION >= QT_VERSION_CHECK(6,6,0))
+        for (const HighlightingRule &rule : std::as_const (highlightingRules))
+#else
         for (const HighlightingRule &rule : qAsConst (highlightingRules))
+#endif
         {
             if (rule.format != whiteSpaceFormat
                 && format (0) == codeBlockFormat) // a literal block
@@ -375,7 +383,7 @@ void Highlighter::highlightYamlBlock (const QString &text)
                     }
                     setFormat (index, length, fi);
                 }
-                index = text.indexOf (rule.pattern, index + qMax (length, 1), &match);
+                index = text.indexOf (rule.pattern, index + std::max (length, 1), &match);
 
                 if (rule.format != whiteSpaceFormat)
                 {
